@@ -3,7 +3,6 @@ from uuid import uuid1
 
 from django import forms
 from django.contrib import admin
-from django.forms.extras.widgets import SelectDateWidget
 
 from entity_event.models import (
     AdminEvent, Event, EventActor, EventSeen, Medium, Source, SourceGroup, Subscription, Unsubscription
@@ -13,7 +12,7 @@ from entity_event.models import (
 class AdminEventForm(forms.ModelForm):
     source = forms.ModelChoiceField(queryset=Source.objects.all())  # initial = Source.objects.get(name='admin')
     text = forms.CharField(widget=forms.Textarea(attrs={'rows': '3', 'cols': '60'}))
-    expires_date = forms.DateField(widget=SelectDateWidget(), required=False)
+    expires_date = forms.DateField(widget=forms.SelectDateWidget(), required=False)
     expires_time = forms.TimeField(label='Expires time (UTC 24 hr) E.g. 18:25', required=False)
 
     class Meta:
@@ -44,6 +43,11 @@ class AdminEventAdmin(admin.ModelAdmin):
     form = AdminEventForm
 
 
+class EventSeenAdmin(admin.ModelAdmin):
+    list_display = ('event', 'medium', 'time_seen')
+    list_filter = ('event__source',)
+
+
 class EventActorInline(admin.TabularInline):
     model = EventActor
 
@@ -54,6 +58,8 @@ class EventSeenInline(admin.TabularInline):
 
 class EventAdmin(admin.ModelAdmin):
     list_display = ('time', 'source')
+    list_filter = ('time', 'source')
+
     inlines = [
         EventActorInline,
         EventSeenInline
@@ -74,6 +80,7 @@ class SourceGroupAdmin(admin.ModelAdmin):
 
 class SubscriptionAdmin(admin.ModelAdmin):
     list_display = ('entity', 'source', 'medium', 'sub_entity_kind', 'only_following')
+    search_fields = ('entity', 'source')
 
 
 class UnsubscriptionAdmin(admin.ModelAdmin):
@@ -83,6 +90,7 @@ class UnsubscriptionAdmin(admin.ModelAdmin):
 admin.site.register(AdminEvent, AdminEventAdmin)
 admin.site.register(Medium, MediumAdmin)
 admin.site.register(Event, EventAdmin)
+admin.site.register(EventSeen, EventSeenAdmin)
 admin.site.register(Source, SourceAdmin)
 admin.site.register(SourceGroup, SourceGroupAdmin)
 admin.site.register(Subscription, SubscriptionAdmin)
