@@ -11,13 +11,11 @@ from django.db.models import Q
 from django.db.models.query import QuerySet
 from django.template.loader import render_to_string
 from django.template import Context, Template
-from django.utils.encoding import python_2_unicode_compatible
 from entity.models import Entity, EntityRelationship
 
 from entity_event.context_serializer import DefaultContextSerializer
 
 
-@python_2_unicode_compatible
 class Medium(models.Model):
     """
     A ``Medium`` is an object in the database that defines the method
@@ -173,12 +171,16 @@ class Medium(models.Model):
         subscription_q_objects = [
             Q(
                 eventactor__entity__in=self.followed_by(sub.subscribed_entities()),
-                source=sub.source
+                source_id=sub.source_id
             )
             for sub in subscriptions if sub.only_following
         ]
         subscription_q_objects.append(
-            Q(source__in=[sub.source for sub in subscriptions if not sub.only_following]))
+            Q(source_id__in=[
+                sub.source_id
+                for sub in subscriptions if not sub.only_following
+            ])
+        )
 
         events = events.cache_related().filter(reduce(or_, subscription_q_objects))
         return events
@@ -271,12 +273,12 @@ class Medium(models.Model):
         subscription_q_objects = [
             Q(
                 eventactor__entity__in=self.followed_by(entity),
-                source=sub.source
+                source_id=sub.source_id
             )
             for sub in subscriptions if sub.only_following
         ]
         subscription_q_objects.append(
-            Q(source__in=[sub.source for sub in subscriptions if not sub.only_following])
+            Q(source_id__in=[sub.source_id for sub in subscriptions if not sub.only_following])
         )
 
         return [
@@ -344,23 +346,29 @@ class Medium(models.Model):
         :returns: A list of tuples in the form ``(event, targets)`` where ``targets`` is a list of entities.
         """
         events = self.get_filtered_events(**event_filters)
-        subscriptions = Subscription.objects.filter(medium=self)
+        subscriptions = Subscription.objects.filter(medium=self).select_related('entity')
+
+        subscribed_cache = {}
+        for sub in subscriptions:
+            subscribed_cache[sub.id] = sub.subscribed_entities()
 
         event_pairs = []
         for event in events:
             targets = []
             for sub in subscriptions:
-                if event.source != sub.source:
+                if event.source_id != sub.source_id:
                     continue
 
-                subscribed = sub.subscribed_entities()
+                subscribed = subscribed_cache[sub.id]
 
                 if sub.only_following:
                     potential_targets = self.followers_of(
                         event.eventactor_set.values_list('entity__id', flat=True)
                     )
                     subscription_targets = list(Entity.objects.filter(
-                        Q(id__in=subscribed), Q(id__in=potential_targets)))
+                        Q(id__in=subscribed),
+                        Q(id__in=potential_targets)
+                    ))
                 else:
                     subscription_targets = list(subscribed)
 
@@ -592,7 +600,6 @@ class Medium(models.Model):
         return {e: e.render(self) for e in events}
 
 
-@python_2_unicode_compatible
 class Source(models.Model):
     """
     A ``Source`` is an object in the database that represents where
@@ -646,7 +653,6 @@ class Source(models.Model):
         return self.display_name
 
 
-@python_2_unicode_compatible
 class SourceGroup(models.Model):
     """
     A ``SourceGroup`` object is a high level categorization of
@@ -679,7 +685,6 @@ class SourceGroup(models.Model):
         return self.display_name
 
 
-@python_2_unicode_compatible
 class Unsubscription(models.Model):
     """
     Because django-entity-event allows for whole groups to be
@@ -739,7 +744,6 @@ class SubscriptionQuerySet(QuerySet):
         return self.select_related('medium', 'source', 'entity', 'sub_entity_kind')
 
 
-@python_2_unicode_compatible
 class Subscription(models.Model):
     """
     Which types of events are available to which mediums is controlled through ``Subscription`` objects. By creating a
@@ -838,12 +842,13 @@ class Subscription(models.Model):
         :rtype: EntityQuerySet
         :returns: A QuerySet of all the entities that are a part of this subscription.
         """
-        if self.sub_entity_kind is not None:
-            sub_entities = self.entity.sub_relationships.filter(
-                sub_entity__entity_kind=self.sub_entity_kind).values_list('sub_entity')
-            entities = Entity.objects.filter(id__in=sub_entities)
+        if self.sub_entity_kind_id is not None:
+            sub_entity_ids = self.entity.sub_relationships.filter(
+                sub_entity__entity_kind_id=self.sub_entity_kind_id
+            ).values_list('sub_entity_id', flat=True)
+            entities = Entity.objects.filter(id__in=sub_entity_ids)
         else:
-            entities = Entity.all_objects.filter(id=self.entity.id)
+            entities = Entity.all_objects.filter(id=self.entity_id)
         return entities
 
 
@@ -1036,7 +1041,6 @@ class EventManager(models.Manager):
         return created_events
 
 
-@python_2_unicode_compatible
 class Event(models.Model):
     """
     ``Event`` objects store information about events. By storing
@@ -1133,7 +1137,6 @@ class AdminEvent(Event):
         proxy = True
 
 
-@python_2_unicode_compatible
 class EventActor(models.Model):
     """
     ``EventActor`` objects encode what entities were involved in an
@@ -1158,7 +1161,6 @@ class EventActor(models.Model):
         return s.format(eventid=eventid, entity=entity)
 
 
-@python_2_unicode_compatible
 class EventSeen(models.Model):
     """
     ``EventSeen`` objects store information about where and when an
@@ -1206,7 +1208,6 @@ def _unseen_event_ids(medium):
     return ids
 
 
-@python_2_unicode_compatible
 class RenderingStyle(models.Model):
     """
     Defines a rendering style. This is used to group together mediums that have
@@ -1220,7 +1221,6 @@ class RenderingStyle(models.Model):
         return '{0} {1}'.format(self.display_name, self.name)
 
 
-@python_2_unicode_compatible
 class ContextRenderer(models.Model):
     """
     ``ContextRenderer`` objects store information about how
